<?php

// pagination class
class Pagination
{
    // total records in table
    private $totalItems;

    // limit of items per page
    private $paginationLimit;

    // total number of pages needed
    private $totalPages;

    // first and back links
    private $firstBack;

    // next and last links
    private $nextLast;

    // where are we among all pages?
    private $where;

    private $currentPage;

    private $startItemNum;

    private $endItemNum;

    public function __construct($wishlists, $paginationLimit)
    {
        //$result = $this->execute($mysqli, "SELECT COUNT(*) FROM `mytopsuserlists` WHERE `Visibility` = ?", "s", ['public']);
        $this->paginationLimit = (int) $paginationLimit;

        if(is_array($wishlists)){
            $this->totalItems = count($wishlists);


            if($this->paginationLimit){
                $this->totalPages = (int)ceil($this->totalItems / $this->paginationLimit);
            }else{
                $this->totalPages = 1;
            }

        }else{
            $this->totalItems = 0;
            $this->totalPages = 0;
        }

        if($paginationLimit > $this->totalItems){
            $itemLimit = $this->totalItems;
        }

        if(isset($_REQUEST['pageno']) && is_int($_REQUEST['pageno'])){
            $this->currentPage = (int) $_GET['pageno'];
        }else{
            if(isset($_REQUEST['pageno']) && (strtolower($_REQUEST['pageno']) == "all")){
                $this->currentPage = "all";
            }else{
                $this->currentPage = 1;
            }
        }
        if(strtolower($this->currentPage) == "all"){
            $this->currentPage = 1;
            $this->totalPages = 1;
            $this->firstBack = "";
            $this->where = "";
            $this->startItemNum = 0;
            $this->endItemNum = $this->totalItems;
        }else{
            // out of range check
            if ($this->currentPage > $this->totalPages) {
                $this->currentPage = $this->totalPages;
            } elseif ($this->currentPage < 1) {
                $this->currentPage = 1;
            }

            // links
            if ($this->currentPage > 1) {
                // backtrack
                $prevpage = $this->currentPage - 1;

                //TODO determine if FB iFrame
                // 'first' and 'back' links
                $this->firstBack = '<nav aria-label="Pagination"><ul class="pagination"><li class="pagination-first">&lt;&lt;</li> <li class="pagination-previous">&nbsp;&nbsp;&lt;</li>';
            } else {
                $this->firstBack = '<nav aria-label="Pagination"><ul class="pagination"><li class="pagination-first disabled">&lt;&lt;</li> <li class="pagination-previous disabled">&nbsp;&nbsp;&lt;</li>';
            }

            $this->where = "<li class='page-count'>(Page $this->currentPage of $this->totalPages)</li>";

            if ($this->currentPage < $this->totalPages) {
                // forward
                $nextpage = $this->currentPage + 1;

                // 'next' and 'last' links
                $this->nextLast = " <li class='pagination-last'>&gt;&gt;</li> <li class='pagination-next'>&gt;&nbsp;&nbsp;</li></ul></nav>";
            } else {
                $this->nextLast = " <li class='pagination-last disabled'>&gt;&gt;</li> <li class='pagination-next disabled'>&gt;&nbsp;&nbsp;</li></ul></nav>";
            }
            $this->startItemNum = (int)(($this->currentPage - 1) * $paginationLimit);

            if ($this->totalItems < ($this->currentPage * $paginationLimit)) {
                $this->endItemNum = $this->totalItems;
            } else {
                $this->endItemNum = $this->currentPage * $paginationLimit;
            }
        }
    }

    private function execute($mysqli, $sql, $types, $params)
    {
        $stmt = mysqli_prepare($mysqli, $sql);
        mysqli_stmt_bind_param($stmt, $types, ...$params);
        mysqli_stmt_execute($stmt);
        return mysqli_stmt_get_result($stmt);
    }

    public function getTotaltems()
    {
        return $this->totalItems;
    }

    public function getCurrentPage()
    {
        return $this->currentPage;
    }

    public function refValues($arr)
    {
        if (strnatcmp(phpversion(), '5.3') >= 0) //Reference is required for PHP 5.3+
        {
            $refs = array();
            foreach ($arr as $key => $value)
                $refs[$key] = &$arr[$key];
            return $refs;
        }
        return $arr;
    }

    // determine what the current page, sets current page and returns the current page records
    public function getCurrentPageItems($start, $end)
    {
        return null;
    }

    // get first and back links
    public function firstBack()
    {
        return $this->firstBack;
    }

    // get next and last links
    public function nextLast()
    {
        return $this->nextLast;
    }

    // get where we are among pages
    public function where()
    {
        return $this->where;
    }

    public function getStartItemNum()
    {
        return $this->startItemNum;
    }

    public function getEndItemNum()
    {

        return $this->endItemNum;
    }

    public function __toString()
    {
        return $this->firstBack() . $this->where() . $this->nextLast();
    }

}